# TyPy

"Tie-pie" is a minimalistic, terminal-based typing test inspired from the likes of [typings.gg](https://typings.gg/) and [monkeytype.gg](https://monkeytype.com/).

![Demonstration](./images/sc1.png "TyPy Demo")
